"use strict";
/**
 * This module holds the class implementation of the AVLNode tree nodes.
 *
 * @module Internal - AVLNode
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AVLNode = void 0;
/**
 * This is the class implementation of the AVL tree nodes.
 *
 * @typeParam K The key type of the node.
 * @typeParam V The value type of the node.
 */
var AVLNode = /** @class */ (function () {
    /**
     * @param key The key of the new node.
     * @param value The value of the new node.
     */
    function AVLNode(key, value) {
        this.key = key;
        this.value = value;
        /**
         * The height of the node: 1 plus the height of the greater height child of the node.
         * Nodes without children have a height of 1.
         */
        this.height = 1;
        /**
         * The size of the node: the amount of nodes (including this node itself)
         * within the node's subtree.
         * @type {number}
         */
        this.size = 1;
        /**
         * The left child of the node.
         */
        this.left = null;
        /**
         * The right child of the node.
         */
        this.right = null;
    }
    return AVLNode;
}());
exports.AVLNode = AVLNode;
