/**
 * This module holds the class implementation of the public API interface
 * {@link IAVLTree `IAVLTree`}.
 *
 * @module Internal - AVLTree
 */
import type { GetKey, IAVLTree, Ord } from '../avl-bst';
/**
 * The class implementation of the public API interface {@link IAVLTree `IAVLTree`}.
 *
 * @typeParam K The key type that is derived from tree values, in order to compare their order.
 * @typeParam V The type of values that are to be stored in the tree.
 */
export declare class AVLTree<K extends Ord, V> implements IAVLTree<K, V> {
    private readonly getKey;
    private root;
    constructor(getKey: GetKey<K, V>);
    isEmpty(): boolean;
    size(): number;
    minValue(): V | null;
    maxValue(): V | null;
    search(key: K): V | null;
    forEach(fn: (element: V) => void): void;
    foldLeft<T>(fn: (acc: T, value: V) => T, seed: T): T;
    foldRight<T>(fn: (acc: T, value: V) => T, seed: T): T;
    keys(): K[];
    values(): V[];
    insert(value: V): boolean;
    delete(key: K): boolean;
    private toArray;
}
