/**
 * This module holds the class implementation of the AVLNode tree nodes.
 *
 * @module Internal - AVLNode
 */
import type { Ord } from '../avl-bst';
/**
 * This is the class implementation of the AVL tree nodes.
 *
 * @typeParam K The key type of the node.
 * @typeParam V The value type of the node.
 */
export declare class AVLNode<K extends Ord = Ord, V = unknown> {
    key: K;
    value: V;
    /**
     * The height of the node: 1 plus the height of the greater height child of the node.
     * Nodes without children have a height of 1.
     */
    height: number;
    /**
     * The size of the node: the amount of nodes (including this node itself)
     * within the node's subtree.
     * @type {number}
     */
    size: number;
    /**
     * The left child of the node.
     */
    left: AVLNode<K, V> | null;
    /**
     * The right child of the node.
     */
    right: AVLNode<K, V> | null;
    /**
     * @param key The key of the new node.
     * @param value The value of the new node.
     */
    constructor(key: K, value: V);
}
